@@ -418,7 +418,7 @@ class OWCrystalCalculator(widget.OWWidget):
 
         # Create a DiffractionResult object holding the results of the diffraction calculations.
         print("CrystalCalculator: Calculating the diffraction results...\n")
-        diffraction_result = diffraction.calculateDiffraction(diffraction_setup, method=METHOD)
+        diffraction_result = diffraction.calculateDiffraction(diffraction_setup, calculation_method=METHOD)
 
         # Create a StokesVector object.
         incoming_stokes_vector = StokesVector([STOKES_S0, STOKES_S1, STOKES_S2, STOKES_S3])
